@@ -12,8 +12,9 @@
 
 from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*paramiko.*')
+filterwarnings(action='ignore', module='.*socket.*')
 
-from paramiko import RSAKey, ServerInterface, Transport, OPEN_SUCCEEDED, AUTH_PARTIALLY_SUCCESSFUL, AUTH_SUCCESSFUL, OPEN_FAILED_ADMINISTRATIVELY_PROHIBITED, OPEN_SUCCEEDED,AUTH_FAILED
+from paramiko import RSAKey, ServerInterface, Transport, OPEN_SUCCEEDED, AUTH_PARTIALLY_SUCCESSFUL, AUTH_SUCCESSFUL, OPEN_FAILED_ADMINISTRATIVELY_PROHIBITED, OPEN_SUCCEEDED, AUTH_FAILED
 from socket import socket, AF_INET, SOCK_STREAM, SOL_SOCKET, SO_REUSEADDR, getfqdn
 from _thread import start_new_thread
 from io import StringIO
@@ -28,6 +29,7 @@ from time import time
 from threading import Event
 from binascii import hexlify
 
+
 class QSSHServer():
     def __init__(self, **kwargs):
         self.auto_disabled = None
@@ -64,7 +66,7 @@ class QSSHServer():
                 self.ip = ip
                 self.port = port
                 self.event = Event()
-                #ServerInterface.__init__(self)
+                # ServerInterface.__init__(self)
 
             def check_bytes(self, string):
                 if isinstance(string, bytes):
@@ -85,14 +87,14 @@ class QSSHServer():
                     username = _q_s.username
                     password = _q_s.password
                     status = 'success'
-                if status =='success':
+                if status == 'success':
                     _q_s.logs.info({'server': 'ssh_server', 'action': 'login', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'dest_ip': _q_s.ip, 'dest_port': _q_s.port, 'username': username, 'password': password})
                     return AUTH_SUCCESSFUL
                 return AUTH_FAILED
 
             def check_channel_exec_request(self, channel, command):
                 if "capture_commands" in _q_s.options:
-                    _q_s.logs.info({'server': 'ssh_server', 'action': 'command', 'src_ip': self.ip, 'src_port': self.port, 'dest_ip': _q_s.ip, 'dest_port': _q_s.port,"data":{"command":self.check_bytes(command)}})
+                    _q_s.logs.info({'server': 'ssh_server', 'action': 'command', 'src_ip': self.ip, 'src_port': self.port, 'dest_ip': _q_s.ip, 'dest_port': _q_s.port, "data": {"command": self.check_bytes(command)}})
                 self.event.set()
                 return True
 
@@ -100,7 +102,7 @@ class QSSHServer():
                 return "password,publickey"
 
             def check_auth_publickey(self, username, key):
-                _q_s.logs.info({'server': 'ssh_server', 'action': 'login', 'src_ip': self.ip, 'src_port': self.port, 'dest_ip': _q_s.ip, 'dest_port': _q_s.port, "username":self.check_bytes(username),'key_fingerprint': self.check_bytes(hexlify(key.get_fingerprint()))})
+                _q_s.logs.info({'server': 'ssh_server', 'action': 'login', 'src_ip': self.ip, 'src_port': self.port, 'dest_ip': _q_s.ip, 'dest_port': _q_s.port, "username": self.check_bytes(username), 'key_fingerprint': self.check_bytes(hexlify(key.get_fingerprint()))})
                 return AUTH_SUCCESSFUL
 
             def check_channel_shell_request(self, channel):
@@ -108,7 +110,7 @@ class QSSHServer():
 
             def check_channel_direct_tcpip_request(self, chanid, origin, destination):
                 return OPEN_SUCCEEDED
-            
+
             def check_channel_pty_request(self, channel, term, width, height, pixelwidth, pixelheight, modes):
                 return True
 
@@ -122,7 +124,7 @@ class QSSHServer():
                 sshhandle = SSHHandle(ip, port)
                 t.start_server(server=sshhandle)
                 conn = t.accept(30)
-                if "interactive" in _q_s.options and conn != None:
+                if "interactive" in _q_s.options and conn is not None:
                     conn.send("Welcome to Ubuntu 20.04.4 LTS (GNU/Linux 5.10.60.1-microsoft-standard-WSL2 x86_64)\r\n\r\n")
                     current_time = time()
                     while True and time() < current_time + 10:
@@ -200,15 +202,14 @@ class QSSHServer():
         return ret
 
     def test_server(self, ip=None, port=None, username=None, password=None):
-        with suppress(Exception):
-            from paramiko import SSHClient, AutoAddPolicy
-            _ip = ip or self.ip
-            _port = port or self.port
-            _username = username or self.username
-            _password = password or self.password
-            ssh = SSHClient()
-            ssh.set_missing_host_key_policy(AutoAddPolicy())  # if you have default ones, remove them before using this..
-            ssh.connect(_ip, port=_port, username=_username, password=_password)
+        from paramiko import SSHClient, AutoAddPolicy
+        _ip = ip or self.ip
+        _port = port or self.port
+        _username = username or self.username
+        _password = password or self.password
+        ssh = SSHClient()
+        ssh.set_missing_host_key_policy(AutoAddPolicy())  # if you have default ones, remove them before using this..
+        ssh.connect(_ip, port=_port, username=_username, password=_password)
 
 
 if __name__ == '__main__':
